@@ -430,7 +430,7 @@ if (Froxlor::isDatabaseVersion('202302030')) {
 	Update::lastStepStatus(0);
 
 	Update::showUpdateStep("Enhancing ssl data table");
-	Database::query("ALTER TABLE `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` RENAME COLUMN `expirationdate` TO `validtodate`;");
+	Database::query("ALTER TABLE `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` CHANGE `expirationdate` `validtodate` datetime DEFAULT NULL;");
 	Database::query("ALTER TABLE `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` ADD `validfromdate` datetime DEFAULT NULL AFTER `ssl_fullchain_file`;");
 	Database::query("ALTER TABLE `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` ADD `issuer` varchar(255) NOT NULL default '' AFTER `validtodate`;");
 	Update::lastStepStatus(0);
@@ -458,3 +458,8 @@ if (Froxlor::isFroxlorVersion('2.0.13')) {
 	Update::showUpdateStep("Updating from 2.0.13 to 2.0.14", false);
 	Froxlor::updateToVersion('2.0.14');
 }
+
+if (Froxlor::isFroxlorVersion('2.0.14')) {
+	Update::showUpdateStep("Updating from 2.0.14 to 2.0.15", false);
+	Froxlor::updateToVersion('2.0.15');
+}
